Shannon and Davio decomposition
-------------------------------

**Header:** ``mockturtle/algorithms/decomposition.hpp``

.. doxygenfunction:: mockturtle::shannon_decomposition
.. doxygenfunction:: mockturtle::positive_davio_decomposition
.. doxygenfunction:: mockturtle::negative_davio_decomposition
